@@ -19,7 +19,7 @@
 //! In the future, the workspaces should be adjusted to store models
 //! for multiple users (multi-user mode).
 
-use self::errors::*;
+use crate::errors::*;
 use dmntk_common::{DmntkError, Result};
 use dmntk_feel::context::FeelContext;
 use dmntk_feel::values::Value;
@@ -28,8 +28,12 @@ use std::collections::HashMap;
 use std::convert::TryFrom;
 use std::sync::{Arc, Mutex};
 
+/// Type alias for keys in workspace hashmap.
+type WorkspaceKey = String;
+
 lazy_static! {
   static ref WORKSPACES: Arc<Mutex<HashMap<String, Workspace>>> = Arc::new(Mutex::new(HashMap::new()));
+  static ref USER_ID: WorkspaceKey = "b8775f65-1f67-4c4d-b3f3-0a362955163c".to_string();
 }
 
 #[derive(Default)]
@@ -51,17 +55,17 @@ impl Workspace {
     let definitions_id = definitions.id().clone();
     let definitions_arc = Arc::new(definitions);
     if self.definitions_by_name.contains_key(&definitions_name) {
-      return Err(definitions_with_name_already_exists(definitions_name));
+      return Err(err_definitions_with_name_already_exists(definitions_name));
     }
     self.definitions_by_name.insert(definitions_name.to_string(), Arc::clone(&definitions_arc));
     if let Some(id) = &definitions_id {
       if self.definitions_by_id.contains_key(id) {
-        return Err(definitions_with_id_already_exists(id.clone()));
+        return Err(err_definitions_with_id_already_exists(id.clone()));
       }
       self.definitions_by_id.insert(id.clone(), Arc::clone(&definitions_arc));
     }
     if self.definitions_by_tag.contains_key(tag) {
-      return Err(definitions_with_tag_already_exists(tag.to_string()));
+      return Err(err_definitions_with_tag_already_exists(tag.to_string()));
     }
     self.definitions_by_tag.insert(tag.to_string(), Arc::clone(&definitions_arc));
     self.definitions.push(definitions_arc);
@@ -102,7 +106,7 @@ impl TryFrom<&str> for InvokedArtifact {
       "decision" => Ok(InvokedArtifact::Decision),
       "bkm" => Ok(InvokedArtifact::BusinessKnowledgeModel),
       "decisionService" => Ok(InvokedArtifact::DecisionService),
-      _ => Err(invalid_invoked_artifact_name(value.to_string())),
+      _ => Err(err_invalid_invoked_artifact_name(value.to_string())),
     }
   }
 }
@@ -111,93 +115,42 @@ impl TryFrom<&str> for InvokedArtifact {
 /// Currently all definitions are stored like for single user.
 /// After successful deployment, the following tuple is returned `(name, id, tag)`.
 pub fn deploy_definitions(tag: &str, definitions: Definitions, replace_existing: bool) -> Result<(String, Option<String>, String)> {
-  let mut workspaces = WORKSPACES.lock().unwrap();
-  if !workspaces.contains_key("1") {
-    let workspace: Workspace = Default::default();
-    workspaces.insert("1".into(), workspace);
-  }
-  let workspace = workspaces.get_mut("1").unwrap();
-  if replace_existing {
-    workspace.replace_definitions(tag, definitions)
+  if let Ok(mut workspaces) = WORKSPACES.lock() {
+    if !workspaces.contains_key(USER_ID.as_str()) {
+      let workspace: Workspace = Default::default();
+      workspaces.insert(USER_ID.clone(), workspace);
+    }
+    if let Some(workspace) = workspaces.get_mut(USER_ID.as_str()) {
+      if replace_existing {
+        workspace.replace_definitions(tag, definitions)
+      } else {
+        workspace.append_definitions(tag, definitions)
+      }
+    } else {
+      Err(err_workspace_not_found(&USER_ID))
+    }
   } else {
-    workspace.append_definitions(tag, definitions)
+    Err(err_can_not_lock_workspace())
   }
 }
 
 /// Evaluates an artifact.
 pub fn evaluate_artifact(ctx: &FeelContext, model_tag: &str, artifact_type: &str, artifact_name: &str) -> Result<Value> {
-  let workspaces = WORKSPACES.lock().unwrap();
-  if let Some(workspace) = workspaces.get("1") {
-    if let Some(definitions) = workspace.get_by_tag(model_tag) {
-      return match InvokedArtifact::try_from(artifact_type)? {
-        InvokedArtifact::Decision => dmntk_evaluator::evaluate_decision_by_name(definitions, artifact_name, ctx),
-        InvokedArtifact::BusinessKnowledgeModel => dmntk_evaluator::evaluate_business_knowledge_model_by_name(definitions, artifact_name, ctx),
-        InvokedArtifact::DecisionService => dmntk_evaluator::eval_decision_service_by_name(definitions, artifact_name, ctx),
-      };
-    }
-  }
-  Err(artifact_not_found(artifact_type.to_owned(), artifact_name.to_owned()))
-}
-
-/// Errors reported by the workspace.
-mod errors {
-  use dmntk_common::DmntkError;
-
-  /// Errors related with operating on workspaces.
-  #[derive(Debug, PartialEq)]
-  pub enum WorkspaceError {
-    ArtifactNotFound(String, String),
-    InvalidInvokedArtifactName(String),
-    DefinitionsWithNameAlreadyExist(String),
-    DefinitionsWithIdAlreadyExist(String),
-    DefinitionsWithTagAlreadyExist(String),
-  }
-
-  impl From<WorkspaceError> for DmntkError {
-    fn from(e: WorkspaceError) -> Self {
-      DmntkError::new("WorkspaceError", &format!("{}", e))
-    }
-  }
-
-  impl std::fmt::Display for WorkspaceError {
-    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-      match self {
-        WorkspaceError::ArtifactNotFound(artifact, name) => {
-          write!(f, "artifact '{}' with name '{}' was not found", artifact, name)
-        }
-        WorkspaceError::InvalidInvokedArtifactName(name) => {
-          write!(f, "'{}' is not a valid name of invoked artifact", name)
-        }
-        WorkspaceError::DefinitionsWithNameAlreadyExist(name) => {
-          write!(f, "definitions with name '{}' already exist in workspace", name)
-        }
-        WorkspaceError::DefinitionsWithIdAlreadyExist(name) => {
-          write!(f, "definitions with identifier '{}' already exist in workspace", name)
-        }
-        WorkspaceError::DefinitionsWithTagAlreadyExist(name) => {
-          write!(f, "definitions with tag '{}' already exist in workspace", name)
+  if let Ok(workspaces) = WORKSPACES.lock() {
+    if let Some(workspace) = workspaces.get(USER_ID.as_str()) {
+      if let Some(definitions) = workspace.get_by_tag(model_tag) {
+        match InvokedArtifact::try_from(artifact_type)? {
+          InvokedArtifact::Decision => dmntk_evaluator::evaluate_decision_by_name(definitions, artifact_name, ctx),
+          InvokedArtifact::BusinessKnowledgeModel => dmntk_evaluator::evaluate_business_knowledge_model_by_name(definitions, artifact_name, ctx),
+          InvokedArtifact::DecisionService => dmntk_evaluator::eval_decision_service_by_name(definitions, artifact_name, ctx),
         }
+      } else {
+        Err(err_artifact_not_found(artifact_type.to_owned(), artifact_name.to_owned()))
       }
+    } else {
+      Err(err_workspace_not_found(&USER_ID))
     }
-  }
-
-  pub fn artifact_not_found(artifact: String, name: String) -> DmntkError {
-    WorkspaceError::ArtifactNotFound(artifact, name).into()
-  }
-
-  pub fn invalid_invoked_artifact_name(name: String) -> DmntkError {
-    WorkspaceError::InvalidInvokedArtifactName(name).into()
-  }
-
-  pub fn definitions_with_name_already_exists(name: String) -> DmntkError {
-    WorkspaceError::DefinitionsWithNameAlreadyExist(name).into()
-  }
-
-  pub fn definitions_with_id_already_exists(name: String) -> DmntkError {
-    WorkspaceError::DefinitionsWithIdAlreadyExist(name).into()
-  }
-
-  pub fn definitions_with_tag_already_exists(name: String) -> DmntkError {
-    WorkspaceError::DefinitionsWithTagAlreadyExist(name).into()
+  } else {
+    Err(err_can_not_lock_workspace())
   }
 }
